# eric7.Preferences.ConfigurationPages.EricServerPage

Module implementing the eric-ide server related settings.

### Global Attributes

None

### Classes

EricServerPage | Class implementing the eric-ide server related settings.

### Functions

create | Module function to create the configuration page.

## EricServerPage

Class implementing the eric-ide server related settings.

### Derived from

ConfigurationPageBase, Ui_EricServerPage

### Class Attributes

None

### Class Methods

None

### Methods

EricServerPage | Constructor
save | Public slot to save the Cooperation configuration.

### Static Methods

None

#### EricServerPage (Constructor)

EricServerPage()

Constructor

#### EricServerPage.save

save()

Public slot to save the Cooperation configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg (ConfigurationDialog)
  reference to the configuration dialog

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up